==> cbplug_dtregister_records1_2_4.zip: dtregister.plugin.php <==
<?php

/**
* @version 1.2.4
* @package Joomla 1.5
* @subpackage CB Plugin for DT Register
* @copyright Copyright (C) 2006 DTH Development
* @copyright contact dthdev@dthdevelopment.com
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
*/

/**
* Tab to display registered events of the Community Builder users
*/

class getRegisteredEvents extends cbTabHandler {

	function getFbPosts() {

		$this->cbTabHandler();

		}
   function event_link($eventId){
	     global  $_CB_database;
	     $params=$this->params;
		 $eventTable =  new TableEvent($_CB_database);
		 $eventTable->load($eventId);
		 $article = $eventTable->getArticle($eventTable->article_id);
		 
		 $Itemid = DTreg::getcomItemId('com_dtregister');
		 
		 if ($this->params->get('eventlink',0) == 1  &&  count($article) > 0) {
			 	$article_ItemId = $eventTable->getArticleItemid($article);
				$reglink = "index.php?option=com_content&view=article&id=".$eventTable->article_id."&Itemid=$article_ItemId";
		 } else {
				$reglink = "index.php?option=com_dtregister&controller=event&task=register&eventId=".$eventId."&Itemid=$Itemid";
		 }
	     
		 return $reglink=JRoute::_($reglink);

	   }
  function getDisplayTab($tab,$user,$ui) {	
     include_once(JPATH_SITE."/administrator/components/com_dtregister/lib/defines.php");
include_once(JPATH_SITE."/administrator/components/com_dtregister/models/event.php");
include_once(JPATH_SITE."/administrator/components/com_dtregister/models/config.php");
include_once(JPATH_SITE."/administrator/components/com_dtregister/helpers/dtregister.php");
global $dtconfig;
$dtconfig = new DtregisterModelConfig(array());
$dtconfig->setGlobal();
	global $_CB_framework, $_CB_database, $ueConfig, $dtconfig;

	$userId=$_CB_framework->myId();	

    $params=$this->params;
    $access=$params->get('access',0);
	$cbCon = new cbConnection( $_CB_framework->myId() );
	
	switch($access){
	    case'0': //Public
		  
		break;
		case'1': //User only
		  if($user->id != $userId){
		     return '';
		  }
		break;
		case'2'://My connections
		  if(!$cbCon->getConnectionDetails($userId,$user->id)){
		     return '';
		  }
		break;
		case'3'://All Registered
		  if(!$userId){
		    return '';
		  }
		break;
		
	}
	
	if($user->id>0)
	{
		
		 $sql="Select count(*)

			 From #__dtregister_user as a			 

			 Where a.user_id =$user->id	and a.status in(0,1) 

			";

	     $_CB_database->setQuery($sql);

		 $total=$_CB_database->loadResult();

		 $entriesNumber=$params->get('number_entries',10);
		 $date=$params->get('date',0);
		 $amount=$params->get('amount',0);

if($entriesNumber ==""){

 $entriesNumber = 10;

}

		$pagingParams = $this->_getPaging(array(),array("entries_"));

		if ($pagingParams["entries_limitstart"] === null) $pagingParams["entries_limitstart"] = "0";

		if ($entriesNumber > $total) $pagingParams["entries_limitstart"] = "0";

		$sql="Select b.slabId , a.register_date,b.title ,b.dtstart as publish_up , d.fee as amount 

			 From #__dtregister_user as a

			 Inner Join #__dtregister_group_event as b

			 On a.eventId=b.slabId			 

             inner join  #__dtregister_fee  d on a.userId= d.user_id
			 
			 Where a.user_id=$user->id	and a.status in(0,1) 

			 Order by a.register_date DESC

			"

			. "\n LIMIT ".($pagingParams["entries_limitstart"]?$pagingParams["entries_limitstart"]:"0").",".$entriesNumber;

		;

		$_CB_database->setQuery($sql);		

		$rowEvents=$_CB_database->loadObjectList();		

       echo $_CB_database->getErrorMsg();

		$return = '';
         $eventTable =  new TableEvent($_CB_database);
		if(count($rowEvents))

		{
            
			$return .= "<table cellpadding=\"5\" cellspacing=\"5\" border=\"0\" width=\"95%\">";

			$return .= "<tr class=\"sectiontableheader\">";

			$return .= "<td align=\"left\"><strong><u>Event Title</u></strong></td>";

             if($amount){
			    $return .= "<td align=\"right\"><strong><u>Amount</u></strong></td>";			
             }
			if($date){
			$return .= "<td align=\"right\"><strong><u>Date Registered</u></strong></td>";			
           }

			$return .= "</tr>";

			for($i=0,$n=count($rowEvents);$i<$n;$i++)

			{				

				$rowEvent=$rowEvents[$i];
                $eventTable->overrideGlobal($rowEvent->slabId);
				$return .= "<tr class=\"sectiontableentry$i\">";			
                $href = $this->event_link($rowEvent->slabId);
				$return .= "<td> <a href='".$href."' >".$rowEvent->title." (". cbFormatDate($rowEvent->publish_up,1,0) .")</a></td>";
	
                if($amount){
			      $return .= "<td align='right'> ". DTreg::displayRate($rowEvent->amount,$dtconfig->getGlobal('currency_code','USD'))."</td>";			
                }
                if($date){
				    $return .= "<td align='right'>". cbFormatDate($rowEvent->register_date,1,0)."</td>";					

                }

				$return .= "</tr>";	
				
				$eventTable->resumeGlobal();

			}		

			if($entriesNumber<$total)

			{

				$return.="<tr><td colspan='4'><div align='center'>".$this->_writePaging($pagingParams,"entries_",$entriesNumber,$total)."</div></td></tr>";

			}

			$return .="</table>";      

			return $return;

		}

		else 

		{

			$return = "<table><tr><td>You have not registered for any events.</td></tr></table>";

	     	return $return;

		}

	}

	else 

	{

		$return = "<table><tr><td>You have not registered for any events.</td></tr></table>";

	     return $return;

	}		

	}

}	

?>

==> cbplug_dtregister_records1_6_1.zip: dtregister.plugin.php <==
<?php

/**
* @version 1.2.5
* @package Joomla 1.6/1.7
* @subpackage CB Plugin for DT Register
* @copyright Copyright (C) 2006 DTH Development
* @copyright contact dthdev@dthdevelopment.com
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
*/

/**
* Tab to display registered events of the Community Builder users
*/

class getRegisteredEvents extends cbTabHandler {

	function getFbPosts() {

		$this->cbTabHandler();

		}
   function event_link($eventId){
	     global  $_CB_database;
	     $params=$this->params;
		 $db = &JFactory::getDBO() ;
		 $eventTable =  new TableEvent($db);
		 $eventTable->load($eventId);
		 $article = $eventTable->getArticle($eventTable->article_id);
		 
		 $Itemid = DTreg::getcomItemId('com_dtregister');
		 
		 if ($this->params->get('eventlink',0) == 1  &&  count($article) > 0) {
			 	$article_ItemId = $eventTable->getArticleItemid($article);
				$reglink = "index.php?option=com_content&view=article&id=".$eventTable->article_id."&Itemid=$article_ItemId";
		 } else {
				$reglink = "index.php?option=com_dtregister&controller=event&task=register&eventId=".$eventId."&Itemid=$Itemid";
		 }
	     
		 return $reglink=JRoute::_($reglink);

	   }
  function getDisplayTab($tab,$user,$ui) {  
     include_once(JPATH_SITE."/administrator/components/com_dtregister/lib/defines.php");
	 
include_once(JPATH_SITE."/administrator/components/com_dtregister/models/event.php");

include_once(JPATH_SITE."/administrator/components/com_dtregister/models/config.php");

include_once(JPATH_SITE."/administrator/components/com_dtregister/helpers/dtregister.php");

global $dtconfig;;
$dtconfig = new DtregisterModelConfig(array());
$dtconfig->setGlobal();
	global $_CB_framework, $_CB_database, $ueConfig, $dtconfig;

	$userId=$_CB_framework->myId();	

    $params=$this->params;
    $access=$params->get('access',0);
	
	$cbCon = new cbConnection( $_CB_framework->myId() );
	
	switch($access){
	    case'0': //Public
		  
		break;
		case'1': //User only
		  if($user->id != $userId){
		     return '';
		  }
		break;
		case'2'://My connections 
		
		  if(!$cbCon->getConnectionDetails($userId,$user->id)){
		     return '';
		  }
		break;
		case'3'://All Registered
		  if(!$userId){
		    return '';
		  }
		break;
		
	}
	
	if($user->id>0)
	{
		
		 $sql="Select count(*)

			 From #__dtregister_user as a			 

			 

			 Where a.user_id =$user->id	  and a.status in(0,1) "; //

	     $_CB_database->setQuery($sql);

		 $total=$_CB_database->loadResult();

		 $entriesNumber=$params->get('number_entries',10);
		 $date=$params->get('date',0);
		 $amount=$params->get('amount',0);

if($entriesNumber ==""){

 $entriesNumber = 10;

}

		$pagingParams = $this->_getPaging(array(),array("entries_"));

		if ($pagingParams["entries_limitstart"] === null) $pagingParams["entries_limitstart"] = "0";

		if ($entriesNumber > $total) $pagingParams["entries_limitstart"] = "0";

		$sql="Select b.slabId , a.register_date,b.title ,b.dtstart as publish_up , d.fee as amount 

			 From #__dtregister_user as a

			 Inner Join #__dtregister_group_event as b

			 On a.eventId=b.slabId			 

             inner join  #__dtregister_fee  d on a.userId= d.user_id
			 
			 Where a.user_id=$user->id	and a.status in(0,1) 

			 Order by a.register_date DESC

			"

			. "\n LIMIT ".($pagingParams["entries_limitstart"]?$pagingParams["entries_limitstart"]:"0").",".$entriesNumber;

		;
		
//Where a.user_id=$user->id	and a.status in(0,1) 
		$_CB_database->setQuery($sql);		

		$rowEvents=$_CB_database->loadObjectList();		

       echo $_CB_database->getErrorMsg();
  
		$return = '';
		 $db = &JFactory::getDBO() ;
         $eventTable =  new TableEvent($db);
		
		if(count($rowEvents))

		{
            
			$return .= "<table cellpadding=\"5\" cellspacing=\"5\" border=\"0\" width=\"95%\">";

			$return .= "<tr class=\"sectiontableheader\">";

			$return .= "<td align=\"left\"><strong><u>Event Title</u></strong></td>";

             if($amount){
			    $return .= "<td align=\"right\"><strong><u>Amount</u></strong></td>";			
             }
			if($date){
			$return .= "<td align=\"right\"><strong><u>Date Registered</u></strong></td>";			
           }

			$return .= "</tr>";

			for($i=0,$n=count($rowEvents);$i<$n;$i++)

			{				

				$rowEvent=$rowEvents[$i];
                $eventTable->overrideGlobal($rowEvent->slabId);
				$return .= "<tr class=\"sectiontableentry$i\">";			
                $href = $this->event_link($rowEvent->slabId);
				$return .= "<td> <a href='".$href."' >".$rowEvent->title." (". cbFormatDate($rowEvent->publish_up,1,0) .")</a></td>";
	
                if($amount){
			      $return .= "<td align='right'> ". DTreg::displayRate($rowEvent->amount,$dtconfig->getGlobal('currency_code','USD'))."</td>";			
                }
                if($date){
				    $return .= "<td align='right'>". cbFormatDate($rowEvent->register_date,1,0)."</td>";					

                }

				$return .= "</tr>";	
				
				$eventTable->resumeGlobal();

			}		

			if($entriesNumber<$total)

			{

				$return.="<tr><td colspan='4'><div align='center'>".$this->_writePaging($pagingParams,"entries_",$entriesNumber,$total)."</div></td></tr>";

			}

			$return .="</table>";      

			return $return;

		}

		else 

		{

			$return = "<table><tr><td>You have not registered for any events.</td></tr></table>";

	     	return $return;

		}

	}

	else 

	{

		$return = "<table><tr><td>You have not registered for any events.</td></tr></table>";

	     return $return;

	}		

	}

}	

?>
